@@ -1,13 +1,13 @@
-# Copyrights 2007 by Mark Overmeer.
+# Copyrights 2007-2008 by Mark Overmeer.
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 1.02.
+# Pod stripped from pm file by OODoc 1.03.
 use warnings;
 use strict;
 
 package Log::Report::Exception;
 use vars '$VERSION';
-$VERSION = '0.14';
+$VERSION = '0.15';
 
 use Log::Report 'log-report';
 use POSIX  qw/locale_h/;
@@ -16,8 +16,6 @@ use POSIX  qw/locale_h/;
 sub new($@)
 {   my ($class, %args) = @_;
     $args{report_opts} ||= {};
-use Carp;
-$args{message} or confess @_;
     bless \%args, $class;
 }
 
@@ -33,9 +31,10 @@ sub inClass($) { $_[0]->message->inClass($_[1]) }
 # if we would used "report" here, we get a naming conflict with
 # function Log::Report::report.
 sub throw(@)
-{   my $self = shift;
-    my $opts = @_ ? { %{$self->{report_opts}}, @_ } : $self->{report_opts};
-    report $opts, $self->reason, $self->message;
+{   my $self   = shift;
+    my $opts   = @_ ? { %{$self->{report_opts}}, @_ } : $self->{report_opts};
+    my $reason = delete $opts->{reason} || $self->reason;
+    report $opts, $reason, $self->message;
 }
 
 1;
